@@ -66,10 +66,11 @@ class _ElementKeywords(KeywordGroup):
                       tap_count= '1', startX='0.5', startY='0.5'):
         """ Scroll screen """
         driver = self._current_application()
-        args = {'startX':float(startX), 'startY':float(startY),
-                'startX':float(endX), 'startY':float(endY),
-                'tapCount':int(tap_count), 'duration':int(duration)}
-        driver.execute_script('mobile: swipe', args)
+        # args = {'startX':float(startX), 'startY':float(startY),
+        #         'startX':float(endX), 'startY':float(endY),
+        #         'tapCount':int(tap_count), 'duration':int(duration)}
+        driver.swipe(start_x=startX, start_Y=startY, end_x=endX, end_Y=endY, duration=duration)
+        # driver.execute_script('mobile: swipe', args)
 
     def scroll_element(self, locator, endX, endY, 
                     duration='1', tap_count= '1', startX='0.5', startY='0.5'):
